sqlobject.tests.test_string_id module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_string_id module

class `sqlobject.tests.test_string_id.` `SOStringID`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `byVal`(val, connection=None)
  `firebirdCreate` = '\n CREATE TABLE so_string_id (\n id VARCHAR(50) NOT NULL PRIMARY KEY,\n val BLOB SUB_TYPE TEXT\n )\n '
  `firebirdDrop` = '\n DROP TABLE so_string_id\n '
  `j` = so_string_id
  `mssqlCreate` = '\n CREATE TABLE so_string_id (\n id VARCHAR(50) PRIMARY KEY,\n val varchar(4000)\n )\n '
  `mssqlDrop` = '\n DROP TABLE so_string_id\n '
  `mysqlCreate` = '\n CREATE TABLE IF NOT EXISTS so_string_id (\n id VARCHAR(50) PRIMARY KEY,\n val TEXT\n )\n '
  `mysqlDrop` = '\n DROP TABLE IF EXISTS so_string_id\n '
  `postgresCreate` = '\n CREATE TABLE so_string_id (\n id VARCHAR(50) PRIMARY KEY,\n val TEXT\n )\n '
  `postgresDrop` = '\n DROP TABLE so_string_id\n '
  `q` = so_string_id
  `sqliteCreate` = '\n CREATE TABLE so_string_id (\n id VARCHAR(50) PRIMARY KEY,\n val TEXT\n )\n '
  `sqliteDrop` = '\n DROP TABLE so_string_id\n '
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `idType`

      alias of `str`

    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_string_id.SOStringID`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_string_id'
  `sybaseCreate` = '\n CREATE TABLE so_string_id (\n id VARCHAR(50) UNIQUE,\n val VARCHAR(50) NULL\n )\n '
  property `val`

`sqlobject.tests.test_string_id.` `test_stringID`()